@@ -1,18 +1,18 @@
 get_predictions_rq <- function(model, fitfram, ci.lvl, ...) {
 
-  if (!is.null(ci.lvl) && !is.na(ci.lvl))
+  if (!is.null(ci.lvl) && !is.na(ci.lvl)) {
     ci <- "confidence"
-  else
+  } else {
     ci <- "none"
+  }
 
-  prdat <-
-    stats::predict(
-      model,
-      newdata = fitfram,
-      interval = ci,
-      level = ci.lvl,
-      ...
-    )
+  prdat <- stats::predict(
+    model,
+    newdata = fitfram,
+    interval = ci,
+    level = ci.lvl,
+    ...
+  )
 
   # get predicted values, on link-scale
   fitfram$predicted <- prdat[, 1]
